package com.yinlihupo.enlish.service.domain.mapper;

import com.yinlihupo.enlish.service.domain.dataobject.ExamWordsJudgeResultDO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

public interface ExamWordsJudgeResultDOMapper {

    int insert(@Param("path") String path);

    List<ExamWordsJudgeResultDO> selectUnfinishedExamWordsJudgeResultDOList(int count);

    int updateMsg(@Param("id") Integer id, @Param("msg") String msg);

    int updateExamWordsJudgeResultDO(@Param("examWordsJudgeResultDO") ExamWordsJudgeResultDO examWordsJudgeResultDO);

    List<ExamWordsJudgeResultDO> selectByPage(@Param("startIndex") Integer startIndex, @Param("pageSize") Integer pageSize);

    Integer selectCount();

    Integer selectUnfinishedCount();

    ExamWordsJudgeResultDO selectDetailById(@Param("id") Integer id);

    List<ExamWordsJudgeResultDO> selectByStudentId(@Param("studentId") Integer studentId);

    List<ExamWordsJudgeResultDO> selectByStudentIdAndLimitTime(@Param("studentId") Integer studentId);

    List<ExamWordsJudgeResultDO> selectByPageAndStudentIds(@Param("startIndex") Integer startIndex, @Param("pageSize") Integer pageSize, @Param("studentIds") List<Integer> studentIds);
}